from contextlib import asynccontextmanager

import redis.asyncio as redis
from fastapi import FastAPI
from fastapi_limiter import FastAPILimiter

from src.neo_neo_todo.routes import control, members, token
from src.neo_neo_todo.utils.database import pool


@asynccontextmanager
async def lifespan(_: FastAPI):
    # Set up pool
    redis_connection = redis.from_url("redis://localhost:6379", encoding="utf8")
    await FastAPILimiter.init(redis_connection)
    print("Starting PostgreSQL DB connection pool and Redis from FastAPI")
    await pool.open()

    yield
    # Clean up the DB pool
    await pool.close()
    await FastAPILimiter.close()
    print("Closing PostgreSQL DB connection pool and Redis from FastAPI")


app = FastAPI(lifespan=lifespan)

# include API routes
app.include_router(control.router)
app.include_router(token.router)
app.include_router(members.router)
