import os
from urllib.parse import urlparse

import psycopg
from psycopg import sql


def generate_test_data() -> None:
    """
    Generate the test data in PostgreSQL database

    Watch for PostgreSQL version changes
    """
    url_parts = urlparse(os.environ["TODO_DB_DATABASE_URL"])

    # Extract connection parameters
    dbname = url_parts.path[1:]
    user_name = url_parts.username
    password = url_parts.password
    host = url_parts.hostname
    port = url_parts.port

    print(
        f"The database name is {dbname}, the username is {user_name}, "
        f"the password is {password}, the host is {host}, the port is {port}"
    )

    with psycopg.connect(
        dbname=dbname, user=user_name, password=password, host=host, port=port
    ) as conn:
        with conn.cursor() as cur:
            cur.execute(
                sql.SQL(
                    """
                    INSERT INTO members (email, password_hash)
                                    VALUES ('member@todo.test',
                                            '$2a$12$EDo2Sr6B1sptfbKK7DqMnO3VNZuNfVuDbpjJa3uUO9S9/lYpu2wzK')
                    """
                )
            )

            cur.execute(
                sql.SQL(
                    """
                    INSERT INTO members (email, password_hash)
                                    VALUES ('member1@todo.test',
                                            '$2b$14$6yXjNza30kPCg3LhzZJfqeCWOLM.zyTiQFD4rdWlFHBTfYzzKJMJe')
                    """
                )
            )

            cur.execute(
                sql.SQL(
                    """
                    INSERT INTO todos (member_id, task)
                                    VALUES (1, 'Test Task 1')
                    """
                )
            )

            cur.execute(
                sql.SQL(
                    """
                    INSERT INTO todos (member_id, task)
                                    VALUES (1, 'Test Task 2')
                    """
                )
            )

            cur.execute(
                sql.SQL(
                    """
                    INSERT INTO todos (member_id, task)
                                    VALUES (1, 'Test Task 3')
                    """
                )
            )

            cur.execute(
                sql.SQL(
                    """
                    INSERT INTO todos (member_id, task)
                                    VALUES (2, 'Test Task 4')
                    """
                )
            )

            cur.execute(
                sql.SQL(
                    """
                    INSERT INTO todos (member_id, task)
                                    VALUES (2, 'Test Task 5')
                    """
                )
            )
            # Commit the changes
            conn.commit()

    print("Finished PostgreSQL test data generation")


if __name__ == "__main__":
    generate_test_data()
